% skript for demonstration on composition and splitting methods
% created by Claude Gittelson

figure;

expEuler = rkParams([0], [0], [1], 'explicit Euler');
oscPlot(expEuler, 0.1, 15, 'b.');
hold on;

impEuler = rkParams([1], [1], [1], 'implicit Euler');
oscPlot(impEuler, 0.1, 15, 'c.');

comp = rkCompParams([impEuler expEuler], [0.5 0.5], 'implicit midpoint rule');
oscPlot(comp, 0.4, 100, 'r.');

figure;

ode = odeOsc([0 1.6]', [0 8]);

hExact = 2^-10;
gauss6 = rkGauss(6);
solExact = feval(gauss6.solver, gauss6, ode, hExact);

oscError(ode, expEuler, [-1:-1:-9], solExact, hExact, 'b');
oscError(ode, impEuler, [0:-1:-8], solExact, hExact, 'b--');

oscError(ode, rkGauss(2), [0:-1:-8], solExact, hExact, 'c');
oscError(ode, rkGauss(4), [0:-1:-8], solExact, hExact, 'c');
oscError(ode, rkGauss(6), [1:-1:-6], solExact, hExact, 'c');

impMid = rkCompParams([impEuler expEuler], [0.5 0.5], 'implicit midpoint rule');
oscError(ode, impMid, [0:-1:-8], solExact, hExact, 'r');
mtd = rkCompYoshida(impMid, 2);
oscError(ode, mtd, [0:-1:-8], solExact, hExact, 'r--');
mtd = rkCompYoshida(mtd, 4);
oscError(ode, mtd, [0:-1:-6], solExact, hExact, 'r--');
mtd = rkCompYoshida(mtd, 6);
oscError(ode, mtd, [0:-1:-6], solExact, hExact, 'r--');

trotter = OscSplit([2 1], [1 1]);
oscError(ode, trotter, [0:-1:-8], solExact, hExact, 'k');
strang = OscSplit([1 2 1], [0.5 1 0.5]);
oscError(ode, strang, [0:-1:-8], solExact, hExact, 'k');
mtd = rkCompSuzuki(strang, 2);
oscError(ode, mtd, [0:-1:-8], solExact, hExact, 'k--');
mtd = rkCompSuzuki(mtd, 4);
oscError(ode, mtd, [0:-1:-6], solExact, hExact, 'k--');