function sol = rk(param, ode, h, tol)
%RK Solve ordinary differential equation with Runge Kutta method.
%  SOL = RK(PARAM, ODE, H) integrates ODE with step size H.

% created by Claude Gittelson


sol.title = sprintf('%s solved with %s, step size %g',ode.name, param.name, h);
sol.method = param;
sol.ode = ode;
sol.h = h;

tic; % start stopwatch 

sol.t = [ode.t0:h:ode.tN]; % time, independant variable
sol.y = zeros(ode.dim,length(sol.t)); % solution, dependant variable
k = zeros(ode.dim,param.s); % slopes
x = zeros(ode.dim,2); % temporary variable
if(nargin>=4) % tolerance for iterations in implicit methods
    sol.tol = tol;
else
    sol.tol = 1e-10;
end
sol.fcalls = 0; % number of function calls

% initial condition
sol.y(:,1) = ode.y0;

% Runge Kutta
for n = 2:length(sol.t)
    [sol.y(:,n), sol.fcalls] = feval(param.step, param, ode, h, sol.tol, sol.y(:,n-1), sol.t(n), k, sol.fcalls);
end

sol.time = toc; % read stopwatch