function param = rkCompParams(method, weight, name)
%RKCOMPPARAMS create parameters for rkComp
% Composution Runge Kutta methods.

% created by Claude Gittelson

if(length(method) ~= length(weight) | nargin < 2)
    return;
end

param.stages = length(weight); % number of stages in composition

param.method = method; % vector of rk methods
param.weight = weight; % vector of weights

param.s = 1; % maximum number of stages in any of the composition steps
for i = 1:param.stages
    if(method(i).s > param.s)
        param.s = method(i).s;
    end
end

param.name = 'Composition';
if(nargin>=3)
    if(ischar(name))
        param.name = name;
    end
end

param.composite = 1; % composition method

% implementation of rk solver
param.step = @rkCompStep;
param.solver = @rk;